@@ -440,6 +440,38 @@ class HanLPClient(object):
             'topk': topk,
         })
 
+    def abstractive_summarization(
+            self,
+            text: str,
+            language: str = None,
+    ) -> str:
+        r""" Abstractive Summarization is the task of generating a short and concise summary that captures the
+        salient ideas of the source text. The generated summaries potentially contain new phrases and sentences that
+        may not appear in the source text.
+
+        Args:
+            text: The text content of the document.
+            language: The language of input text or tokens. ``None`` to use the default language on server.
+
+        Returns:
+            Summarization.
+
+        Examples::
+
+            HanLP.abstractive_summarization('''
+            每经AI快讯，2月4日，长江证券研究所金属行业首席分析师王鹤涛表示，2023年海外经济衰退，美债现处于历史高位，
+            黄金的趋势是值得关注的；在国内需求修复的过程中，看好大金属品种中的铜铝钢。
+            此外，在细分的小品种里，建议关注两条主线，一是新能源，比如锂、钴、镍、稀土，二是专精特新主线。（央视财经）
+            ''')
+            # Output:
+            '长江证券：看好大金属品种中的铜铝钢'
+        """
+        assert text, 'Text has to be non-empty.'
+        return self._send_post_json(self._url + '/abstractive_summarization', {
+            'text': text,
+            'language': language or self._language,
+        })
+
     def grammatical_error_correction(self, text: Union[str, List[str]], language: str = None) \
             -> Union[str, List[str]]:
         """ Grammatical Error Correction (GEC) is the task of correcting different kinds of errors in text such as
@@ -468,3 +500,57 @@ class HanLPClient(object):
                                         {'text': text,
                                          'language': language or self._language})
         return response
+
+    def text_classification(self, text: Union[str, List[str]], model, topk=False, prob=False) -> Union[
+        str, Dict[str, float], List[Union[str, Dict[str, float]]]]:
+        """
+        Text classification is the task of assigning a sentence or document an appropriate category.
+        The categories depend on the chosen dataset and can range from topics.
+
+        Args:
+            text: A document or a list of documents.
+            model: The model to use for prediction.
+            topk: ``True`` or ``int`` to return the top-k labels.
+            prob: Return also probabilities.
+
+        Returns:
+
+            Classification results.
+        """
+        response = self._send_post_json(self._url + '/text_classification',
+                                        {'text': text, 'model': model, 'topk': topk, 'prob': prob})
+        return response
+
+    def language_identification(self, text: Union[str, List[str]], topk=False, prob=False) -> Union[
+        str, Dict[str, float], List[Union[str, Dict[str, float]]]]:
+        """
+        Identify the language of a given text.
+
+        Args:
+            text: A document or a list of documents.
+            topk: ``True`` or ``int`` to return the top-k languages.
+            prob: Return also probabilities.
+
+        Returns:
+
+            Identified language in `ISO 639-1 codes`_.
+
+        Examples::
+
+            HanLP.language_identification(
+            'In 2021, HanLPv2.1 delivers state-of-the-art multilingual NLP techniques.')
+            'en'
+            lang, prob = HanLP.language_identification(
+            '2021年、HanLPv2.1は次世代の最先端多言語NLP技術を本番環境に導入します。', prob=True)
+            ('ja', 0.9976244568824768)
+            HanLP.language_identification(
+            '2021年 HanLPv2.1为生产环境带来次世代最先进的多语种NLP技术。', topk=2)
+            ['zh', 'ja']
+            HanLP.language_identification(
+            '2021年 HanLPv2.1为生产环境带来次世代最先进的多语种NLP技术。', topk=3, prob=True)
+            {'zh': 0.3952908217906952, 'en': 0.37189167737960815, 'ja': 0.056213412433862686}
+
+        .. _ISO 639-1 codes:
+           https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes
+        """
+        return self.text_classification(text, 'lid', topk, prob)
